@@ -6,11 +6,14 @@
 package Tangence::Message;
 
 use strict;
+use warnings;
 
-use Tangence::Constants;
+our $VERSION = '0.02';
 
 use Carp;
 
+use Tangence::Constants;
+
 use Encode qw( encode_utf8 decode_utf8 );
 
 # Normally we don't care about hash key order. But, when writing test scripts
