@@ -6,6 +6,10 @@
 package Tangence::ObjectProxy;
 
 use strict;
+use warnings;
+
+our $VERSION = '0.02';
+
 use Carp;
 
 use Tangence::Constants;
