@@ -6,6 +6,9 @@
 package Tangence::Stream;
 
 use strict;
+use warnings;
+
+our $VERSION = '0.02';
 
 use base qw( IO::Async::Sequencer );
 
